AuthenticationRepository class

Constructors

AuthenticationRepository({FirebaseAuth? firebaseAuth})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → Future<String?>
no setter

Methods

deleteToken() → Future<void>
hasToken() → Future<bool>
isAnonymous() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
persistToken(String token) → Future<void>
signInAnonymously() → Future<User?>
signInWithCredentials(String email, String password) → Future<User?>
signUp(String email, String password) → Future<User?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited