RemoteRepository<T extends CloudSyncable> class abstract

An interface for interacting with a remote data source for CloudSyncable entities.

Implementers

Constructors

RemoteRepository()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchItemsByServerWrittenTimeRange({required DateTime to, DateTime? from}) → Future<List<T>>
Fetch items from the remote server within the specified server-written timestamp range.
getLatestServerSyncTime() → Future<DateTime?>
Get the latest server sync timestamp from the remote data source.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pushUnsyncedItems(List<T> items) → Future<void>
Synchronize the given items with the remote server.
toString() → String
A string representation of this object.
inherited
watchingNewRecordsUpdates() → Future<Stream<bool>>
Stream that emits true when there are new or updated records in the remote repository

Operators

operator ==(Object other) → bool
The equality operator.
inherited